@@ -16,13 +16,12 @@ def lambda_handler(event, _):
     logger.info(json.dumps(event))
     logger.info(f"LOG_LEVEL: {log_level} ")
 
-    token = event['Token']
-    execution_id = event['ExecutionId']
-
-    logger.info(f"token: {token} \n \
-                execution_id: {execution_id}")
-
-    step_functions_client.send_task_success(
-        taskToken=token,
-        output=json.dumps(
-            {'message': f'this works'}))
+    if 'Records' in event:
+        for record in event['Records']:
+            if record["eventSource"] == "aws:sqs":
+                body = json.loads(record["body"])
+                token = body['TaskToken']
+                step_functions_client.send_task_success(
+                    taskToken=token,
+                    output=json.dumps(
+                        {'message': f'this works'}))
